From 929a369679ca8ae73a210de78abacdff9a129dce Mon Sep 17 00:00:00 2001
From: Bernhard Reutner-Fischer <rep.dot.nop@gmail.com>
Date: Wed, 17 Nov 2010 11:55:21 +0100
Subject: [PATCH 1/4] fetch: rename suppports_srcrev to supports_srcrev

osc had it already spelled correctly?!

Signed-off-by: Bernhard Reutner-Fischer <rep.dot.nop@gmail.com>
---
 lib/bb/fetch/__init__.py |    6 +++---
 lib/bb/fetch/bzr.py      |    2 +-
 lib/bb/fetch/git.py      |    2 +-
 lib/bb/fetch/hg.py       |    2 +-
 lib/bb/fetch/repo.py     |    2 +-
 lib/bb/fetch/svn.py      |    2 +-
 6 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/lib/bb/fetch/bzr.py b/lib/bb/fetch/bzr.py
index 3ca125f..4cd51cb 100644
--- a/lib/bb/fetch/bzr.py
+++ b/lib/bb/fetch/bzr.py
@@ -116,7 +116,7 @@ class Bzr(Fetch):
                 pass
             raise t, v, tb
 
-    def suppports_srcrev(self):
+    def supports_srcrev(self):
         return True
 
     def _revision_key(self, url, ud, d):
diff --git a/lib/bb/fetch/git.py b/lib/bb/fetch/git.py
index 4acaa87..2b252f3 100644
--- a/lib/bb/fetch/git.py
+++ b/lib/bb/fetch/git.py
@@ -154,7 +154,7 @@ class Git(Fetch):
         os.chdir(ud.clonedir)
         bb.utils.prunedir(codir)
 
-    def suppports_srcrev(self):
+    def supports_srcrev(self):
         return True
 
     def _contains_ref(self, tag, d):
diff --git a/lib/bb/fetch/hg.py b/lib/bb/fetch/hg.py
index ca3a084..264a52d 100644
--- a/lib/bb/fetch/hg.py
+++ b/lib/bb/fetch/hg.py
@@ -162,7 +162,7 @@ class Hg(Fetch):
                 pass
             raise t, v, tb
 
-    def suppports_srcrev(self):
+    def supports_srcrev(self):
         return True
 
     def _latest_revision(self, url, ud, d):
diff --git a/lib/bb/fetch/repo.py b/lib/bb/fetch/repo.py
index 4794796..bafdb2a 100644
--- a/lib/bb/fetch/repo.py
+++ b/lib/bb/fetch/repo.py
@@ -95,7 +95,7 @@ class Repo(Fetch):
         # Create a cache
         runfetchcmd("tar --exclude=.repo --exclude=.git -czf %s %s" % (ud.localpath, os.path.join(".", "*") ), d)
 
-    def suppports_srcrev(self):
+    def supports_srcrev(self):
         return False
 
     def _build_revision(self, url, ud, d):
diff --git a/lib/bb/fetch/svn.py b/lib/bb/fetch/svn.py
index c236e41..538b4c2 100644
--- a/lib/bb/fetch/svn.py
+++ b/lib/bb/fetch/svn.py
@@ -168,7 +168,7 @@ class Svn(Fetch):
                 pass
             raise t, v, tb
 
-    def suppports_srcrev(self):
+    def supports_srcrev(self):
         return True
 
     def _revision_key(self, url, ud, d):
diff --git a/lib/bb/fetch/__init__.py b/lib/bb/fetch/__init__.py
index 1cd0faf..0d0fa35 100644
--- a/lib/bb/fetch/__init__.py
+++ b/lib/bb/fetch/__init__.py
@@ -341,11 +341,11 @@ def get_srcrev(d):
 
     scms = []
 
     # Only call setup_localpath on URIs which suppports_srcrev()
     urldata = init(bb.data.getVar('SRC_URI', d, 1).split(), d, False)
     for u in urldata:
         ud = urldata[u]
-        if ud.method.suppports_srcrev():
+        if ud.method.supports_srcrev():
             if not ud.setup:
                 ud.setup_localpath(d)
             scms.append(u)
@@ -560,7 +560,7 @@ class Fetch(object):
         """
         return False
 
-    def suppports_srcrev(self):
+    def supports_srcrev(self):
         """
         The fetcher supports auto source revisions (SRCREV)
         """
@@ -341,11 +341,11 @@ def get_srcrev(d):
     scms = []
 
-    # Only call setup_localpath on URIs which suppports_srcrev()
+    # Only call setup_localpath on URIs which supports_srcrev()
     urldata = init(bb.data.getVar('SRC_URI', d, 1).split(), d, False)
     for u in urldata:
-- 
1.7.2.3

